@@ -132,7 +132,9 @@ class Stock:
 		self.df_month = get_month_data(self.ticker)
 
 	def due_diligence(self):
-		self._get_summary()
+		'''
+		All of the functions I created for doing due diligence on a stock.
+		''' 
 
 		# Code reuse
 
@@ -195,8 +197,6 @@ class Stock:
 			soup = _get_soup(BASE_URL)
 			pass
 
-		# _basic_stats('uuuu')
-
 		def _price_target(self, exchange='NASDAQ'): # Automatically find correct stock exchange
 			soup = _get_soup(BASE_URL)
 			table = soup.find('table', {'class': "scroll-table"})
@@ -222,11 +222,6 @@ class Stock:
 			analyst_price_targets = analyst_price_targets.set_index('Date')
 			return price_target, percentage, analyst_price_targets
 
-
-		# html = soup.prettify("utf-8") Good way to visualize what your Python code is visualizing
-		# with open('output1.html', 'w', encoding='utf-8') as f:
-		# 	f.write(str(_price_target('AAPL')))
-
 		def _price_predictions(self):
 			BASE_URL = f'https://www.barchart.com/stocks/quotes/{self.ticker}/opinion'
 			soup = _get_soup(BASE_URL)
@@ -318,6 +313,9 @@ class Stock:
 			'Beta (5Y Monthly): ' + div.find('span', {'data-reactid': '61'}).get_text(), 'PE Ratio (TTM): ' + div.find('span', {'data-reactid': '66'}).get_text()
 
 		def _short_selling(self):
+			'''
+			Returns a stocks short_selling information
+			'''
 			BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
 			soup = _get_soup(BASE_URL)
 
@@ -327,6 +325,9 @@ class Stock:
 
 
 		def _put_call_ratio(self): 
+			'''
+			Returns various information regarding the put call ratio of a stock.
+			'''
 			BASE_URL = f'https://www.alphaquery.com/stock/{self.ticker}/volatility-option-statistics/120-day/put-call-ratio-oi'
 			soup = _get_soup(BASE_URL)
 
@@ -468,6 +469,11 @@ class Stock:
 			recent_purchases_df = recent_purchases_df.set_index('Date').sort_index(ascending=False)
 
 			return owners_df, mutual_funds_df, recent_purchases_df.tail()
+	
+		# Have not decided how I want to format returning all of this information
+		return _get_summary(), _basic_stats(), _price_target(), _price_predictions(), 
+		_ta_indictators(), _news_sentiments(), _financials(), _short_selling(), _put_call_ratio(), _find_competition(), _etfs(), 
+		_insider_trading(), _social_media_sentiment(), _catalysts(), _big_money()
 
 	def __str__(self):
 		return self.ticker
